==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGeoJSONReader.java <==
// java wrapper for vtkGeoJSONReader object
//

package vtk;
import vtk.*;

public class vtkGeoJSONReader extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStringInput_4(String id0);
  public void SetStringInput(String id0)
    { SetStringInput_4(id0); }

  private native String GetStringInput_5();
  public String GetStringInput()
    { return GetStringInput_5(); }

  private native void SetStringInputMode_6(boolean id0);
  public void SetStringInputMode(boolean id0)
    { SetStringInputMode_6(id0); }

  private native boolean GetStringInputMode_7();
  public boolean GetStringInputMode()
    { return GetStringInputMode_7(); }

  private native void StringInputModeOn_8();
  public void StringInputModeOn()
    { StringInputModeOn_8(); }

  private native void StringInputModeOff_9();
  public void StringInputModeOff()
    { StringInputModeOff_9(); }

  private native void SetTriangulatePolygons_10(boolean id0);
  public void SetTriangulatePolygons(boolean id0)
    { SetTriangulatePolygons_10(id0); }

  private native boolean GetTriangulatePolygons_11();
  public boolean GetTriangulatePolygons()
    { return GetTriangulatePolygons_11(); }

  private native void TriangulatePolygonsOn_12();
  public void TriangulatePolygonsOn()
    { TriangulatePolygonsOn_12(); }

  private native void TriangulatePolygonsOff_13();
  public void TriangulatePolygonsOff()
    { TriangulatePolygonsOff_13(); }

  private native void SetOutlinePolygons_14(boolean id0);
  public void SetOutlinePolygons(boolean id0)
    { SetOutlinePolygons_14(id0); }

  private native boolean GetOutlinePolygons_15();
  public boolean GetOutlinePolygons()
    { return GetOutlinePolygons_15(); }

  private native void OutlinePolygonsOn_16();
  public void OutlinePolygonsOn()
    { OutlinePolygonsOn_16(); }

  private native void OutlinePolygonsOff_17();
  public void OutlinePolygonsOff()
    { OutlinePolygonsOff_17(); }

  private native void SetSerializedPropertiesArrayName_18(String id0);
  public void SetSerializedPropertiesArrayName(String id0)
    { SetSerializedPropertiesArrayName_18(id0); }

  private native String GetSerializedPropertiesArrayName_19();
  public String GetSerializedPropertiesArrayName()
    { return GetSerializedPropertiesArrayName_19(); }

  public vtkGeoJSONReader() { super(); }

  public vtkGeoJSONReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-15-armv7h.pkg.tar.xz: vtk/vtkGeoJSONReader.java <==
// java wrapper for vtkGeoJSONReader object
//

package vtk;
import vtk.*;

public class vtkGeoJSONReader extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStringInput_4(String id0);
  public void SetStringInput(String id0)
    { SetStringInput_4(id0); }

  private native String GetStringInput_5();
  public String GetStringInput()
    { return GetStringInput_5(); }

  private native void SetStringInputMode_6(boolean id0);
  public void SetStringInputMode(boolean id0)
    { SetStringInputMode_6(id0); }

  private native boolean GetStringInputMode_7();
  public boolean GetStringInputMode()
    { return GetStringInputMode_7(); }

  private native void StringInputModeOn_8();
  public void StringInputModeOn()
    { StringInputModeOn_8(); }

  private native void StringInputModeOff_9();
  public void StringInputModeOff()
    { StringInputModeOff_9(); }

  private native void SetTriangulatePolygons_10(boolean id0);
  public void SetTriangulatePolygons(boolean id0)
    { SetTriangulatePolygons_10(id0); }

  private native boolean GetTriangulatePolygons_11();
  public boolean GetTriangulatePolygons()
    { return GetTriangulatePolygons_11(); }

  private native void TriangulatePolygonsOn_12();
  public void TriangulatePolygonsOn()
    { TriangulatePolygonsOn_12(); }

  private native void TriangulatePolygonsOff_13();
  public void TriangulatePolygonsOff()
    { TriangulatePolygonsOff_13(); }

  private native void SetOutlinePolygons_14(boolean id0);
  public void SetOutlinePolygons(boolean id0)
    { SetOutlinePolygons_14(id0); }

  private native boolean GetOutlinePolygons_15();
  public boolean GetOutlinePolygons()
    { return GetOutlinePolygons_15(); }

  private native void OutlinePolygonsOn_16();
  public void OutlinePolygonsOn()
    { OutlinePolygonsOn_16(); }

  private native void OutlinePolygonsOff_17();
  public void OutlinePolygonsOff()
    { OutlinePolygonsOff_17(); }

  private native void SetSerializedPropertiesArrayName_18(String id0);
  public void SetSerializedPropertiesArrayName(String id0)
    { SetSerializedPropertiesArrayName_18(id0); }

  private native String GetSerializedPropertiesArrayName_19();
  public String GetSerializedPropertiesArrayName()
    { return GetSerializedPropertiesArrayName_19(); }

  public vtkGeoJSONReader() { super(); }

  public vtkGeoJSONReader(long id) { super(id); }
  public native long   VTKInit();

}
